@@ -1,13 +1,16 @@
 /* -*- indent-tabs-mode: nil; js-indent-level: 2 -*- */
-/* This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
+/*
+ * Any copyright is dedicated to the Public Domain.
+ * http://creativecommons.org/licenses/publicdomain/
+ * Contributor: Jason Orendorff
+ */
 
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 452573;
-var summary = 'Do not assert with JIT: boxed.isUndefined() || boxed.isBoolean()';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 441477-01;
+var summary = '';
+var actual = 'No Exception';
+var expect = 'No Exception';
+
 
 //-----------------------------------------------------------------------------
 test();
@@ -17,10 +20,20 @@ function test()
 {
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
-
-  for(var j=0;j<5;++j) typeof void /x/;
-
-
+ 
+  try
+  {
+    for (i = 0; i < 5;) 
+    { 
+      if (i > 5) 
+        throw "bad"; 
+      i++; 
+      continue; 
+    }
+  }
+  catch(ex)
+  {
+    actual = ex + '';
+  }
   reportCompare(expect, actual, summary);
 }
